Coverage for test_utils: 100%

# Coverage for test_utils : 100%

## 5 statements 5 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 | # -*- coding: utf-8 -*- import pytest @pytest.mark.parametrize('data', [ ( [ {'col1': 'test01', 'col2': 'test02', 'col3': 'test03'}, {'col1': 'long-string-data-test01', 'col2': 'test02', 'col3': 'this-is-also-log-data'} ] ), ]) def test_put(data): """test put function""" from jungle.utils import lod_format lod_format(data) assert False